function [symbol] = dmtsymb(data, carriers, bitsHz, QAM_PSK, ifft_size, format)
%TIMESIG Generates a DMT (OFDM) symbol
%timesig = dmtsymb(data, carriers, bitsHz, QAM_PSK, ifft_size, format)
%data : contains a vector of the data to transmit in integer
%	i.e. for BPSK: [0,1,1,0,1,0,0,0,1....]
%	QPSK: [3,1,2,0,2,1,2,3,0....]
%	16QAM: [15,2,5,1,0,14 ....]
%	Note: The length of data should match the number of carriers.
%	If not a warning message will be generated, and they will be
%	zero padded.
%	If the data is given as -1 then that carrier is no transmitted on
%carriers : This is a list of the carriers to use.
%	The default is to use all the carriers available.
%bitsHz : Sets the bits/Hz modulation. i.e. 2 - QPSK, 4 - 16QAM, 16PSK
%QAM_PSK : Set whether to use PSK or QAM modulation
%	QAM_PSK : 0 - PSK, 1 - QAM
%ifft_size : size of the ifft used to generate the symbol.
%	The default ifft_size will be calculated based on the
%	size of the data given, the number of carriers, and the format
%format : Determines whether a real or complex result is generated
%	format : 'real', A real waveform is generated. The positive and
%	negative half spectrums are set to be conjugates of one another
%	Only the positive carriers can be set (Lower half of the spectrum).
%	i.e. valid carriers are	from 1 : ifft_size/2
%	format : 'complex', A complex waveform is generated, allowing all
%	carriers to be set. Note : the default is 'real'
%	NOTE: I have only implemented upto 8QAM, any PSK can be handled

if (~strcmp(format,'complex'))
	format = 'real';
end

MaxMod = 2^bitsHz-1;
DataLen = length(data);
CarrLen = length(carriers);

%Check that the number of carriers is legal
if (((strcmp(format,'real'))&(CarrLen>ifft_size/2))|...
	((strcmp(format,'complex'))& (CarrLen>ifft_size))),
	error('Number of carriers is to many to fit into ifft_size');
end

if (DataLen > CarrLen)
	error('Too much data to fit into one data symbol');
end

if (DataLen < CarrLen)
	disp('WARNING: Data is shorter then number of carriers, it will be zero padded');
	data = [data zeros(1,CarrLen-DataLen)];
end
maxcarr = max(carriers);
if (((maxcarr > ifft_size/2)&strcmp(format,'real'))|...
	(maxcarr > ifft_size))
	error('Carriers too high to fit in IFFT')
end
%Check if the modulation scheme is legal
%(Only check the first 50 to reduce computational overhead)
if (max(data(1:min(50:DataLen))) > MaxMod)
	error('Data has input which is too big for specified modulation scheme');
end


if (length(find(data == -1)) > 0)
	%remove carriers with data of -1
	index = find(data ~= -1);
	carriers = carriers(index);
	data = data(index);
end;
%Convert input data into phase and amplitude based on the modulation scheme,
%ready to set the spectrum
%Generate lookup tables to convert from the data to the Complex spectral components
if (QAM_PSK == 1),
	%QAM
	if (bitsHz == 1),
		%BPSK
		ModMag = [ 1 1 ];
		ModPh = [ 0 pi ];
	elseif (bitsHz == 2),
		%QPSK
		ModMag = ones(1,4);
		ModPh = [0 pi/2 pi 3*pi/2];
	elseif (bitsHz == 3),
		%8QAM
		ModMag = [ 0.5*ones(1,4) ones(1,4)];
		ModPh = [ pi/4:pi/2:2*pi, 0:pi/2:3*pi/2];
	else
		error('Modulation 16QAM and higher currently unsupported');
	end

elseif (QAM_PSK == 0),
	%PSK
	ModMag = ones(1,2^bitsHz);
	ModPh = 0:2*pi/(2^bitsHz):2*pi*(1-1/(2^bitsHz));
end
%Convert the magnitude and phase into complex numbers
[X,Y] = pol2cart(ModPh,ModMag);
ModTable = X+sqrt(-1)*Y;

%=============================================
% Use the modulation lookup table to find the
% spectral components for the data
%=============================================
ModData = ModTable(data+1);
%This is a work around for a bug in Matlab 4.2
%It does not dereference  a table correctly when the index vector 
%is all ones;
if (data == zeros(size(data))),
	ModData = ones(size(data)).*ModTable(1);
else
	ModData = ModTable(data+1);
end

if (strcmp(format,'real')),
	%Now assign the data into carriers
	Spect = zeros(1,ifft_size/2);	%Start with a blank spectrum which
					%is half the size of the ifft
	Spect(carriers) = ModData;	%Put the data is the carriers from
					%lowest to highest
	%Copy the conjugate from the lower half into the upper half to
	%make it a real spectrum
	Spect = [ 0 Spect(2:ifft_size/2) 0 conj(Spect(ifft_size/2:-1:2))];
else
	Spect = zeros(1,ifft_size);
	Spect(carriers) = ModData;
end

%Take the IFFT to convert the spectrum back
symbol = ifft(Spect);

%Remove very small complex components from the real signal
if (strcmp(format,'real'))
	symbol = real(symbol);
end
