function [colsort,objang] = collision(obj,l2)
%COLLISION finds intercept of line to a 2D polygon
% [col,objang] = collision(object,line)
% The intercepts are only returned if they fall in the bounds of the line
% object  - complex vertices of closed polygon
% line    - two points to find the intercept with.
% colsort - intercept point between the line and the object (complex coordinate)
% objang  - angle of the surface of the object

%Version 1.1
%4/8/00 version 1.1
%If the line passes directly through the corner of the vertices on odd number of
%intercept points is returned. Duplicate collision points are removed. 
%5/8/00 version 1.2
%Fuzz is added to the line equations to prevents the line passing directly through
%the exact corner of an object.

%Add fuzz to the line points
l1 = l2+(randn(size(l2))+i*randn(size(l2)))*sqrt(eps);
%Calculate the line equations for the object and the line
objc = [ obj obj(1)];
[m, c]= lineequ(objc);
[ml,cl] = lineequ(l1);

xcol = zeros(length(ml),length(c));
%Find parallel lines
dm = ml-m;	
ind = find(abs(dm)<eps);	%If the difference of the gradient is zero the lines are parallel
dm(ind) = eps*ones(size(ind));

indz = find((ml-m)==0);
m(indz) = m(indz)+eps*100;
xcol = (c - cl)./(ml-m);	%Find the x intercept between the line and a line on the object

indf = find(abs(dm)==inf); %if dm is infinite then one of the lines is vertical

xcol(indf) = c(indf);		%if one of the lines is vertical the x intercept = c (from y = mx+c)
xcol(ind) = ones(size(ind))*inf;	%parallel lines never meet

%Find vertical lines on the object
ind = find(abs(m)==inf);
xcol(ind) = real(objc(ind));

%Calculate the Y intercept of the lines
%if the line gradient is really large consider it to be vertical, use the object line
if (abs(ml) > 1e6)
   %disp('inf gain');
   xcol = real(l1(1))*ones(size(m));
   ycol = xcol.*m+c;
else
   ycol = xcol.*ml+cl;
end

xo1 = real(objc(1:(length(objc)-1)));
xo2 = real(objc(2:length(objc)));
yo1 = imag(objc(1:(length(objc)-1)));
yo2 = imag(objc(2:length(objc)));
xlmin = min(real(l1));
xlmax = max(real(l1));
ylmin = min(imag(l1));
ylmax = max(imag(l1));

%ep = 1e-6;
ep = eps*1e4;

%Check to see if the intercept between the line and the lines of the object, is
%within the x and y boundaries of the object lines and the intercepting line
%if so then the intercept line passes through the object at that point.
%ep is used to get around preceision problems with vertical and horizontal lines
ind = find((xcol>=(min([xo1;xo2])-ep))&(xcol<=(max([xo1;xo2])+ep))&((xcol>=(xlmin-ep))&(xcol<=(xlmax+ep)))...
   &((ycol>=(min([yo1;yo2])-ep))&(ycol<=(max([yo1;yo2])+ep))&((ycol>=(ylmin-ep))&(ycol<=(ylmax+ep)))));

objang1 = lineang(objc);
%lineang = atan(ml);
xbound = xcol(ind);
ybound = ycol(ind);
objang2 = objang1(ind);

%Find unique points
if  ~isempty(ind)
%disp(['xbound'])
%size(xbound)
[s, I] = sortrows([xbound',ybound']);
if length(xbound) > 1
ds = diff(s);
%disp('ds')
%size(ds)
ind2 = find(((abs(ds(:,1))<eps*100)&(abs(ds(:,2))<eps*100)));
ind = setxor(1:length(I),ind2);
iout = I(ind);
else
   iout = 1;
end

lnang = lineang(l1);

col = xbound(iout)+i*ybound(iout);
objang = objang2(iout);
colsort = col;
else
   colsort = [];
   objang = [];
end

%=======================================
function [ang] = lineang(obj)
%LINEANG Calculates the line angles for a set of complex data points
%[ang] = lineang(obj)
%obj - complex x,y points. 
%eg. lineang([-1-i 0])
v = obj(2:length(obj))-obj(1:(length(obj)-1));
ang = atan2(imag(v),real(v));

%=======================================
function [m,c] = lineequ(obj)
%LINEEQU Calculates the line equations for a set of complex data points
%[m,c] = lineequ(obj)
%m - gradient, m will smaller in length than obj by one
%c - intercept, c will smaller in length than obj by one
%obj - complex x,y points. 

%Eric Lawrey 23/11/99
v = obj(2:length(obj))-obj(1:(length(obj)-1));

[s,f] = warning;	%Get the current warning state
warning off;		%Turn warnings off so that div 0 warnings aren't generated			
m = imag(v)./real(v);
ss = ['warning ' s];
eval(ss);			%Return warnings to previous state

c = imag(obj(2:length(obj))) - m.*real(obj(2:length(obj)));
ind = find((m==inf)|(m==-inf));
c(ind) = real(obj(ind));

%=======================================
function lnth = linelength(lines)
%LINELENGTH returns the length of line segments
%lnth = linelength(lines)
%lines is a row vector with line vertices specified
%as complex coordinates.
lnth = abs(lines(2:length(lines))-lines(1:(length(lines)-1)));
