function [intercept_points, obj_surface_angle, cum_atten, collision_object] = rayline(objects,line_ends)
%RAYLINE Traces a line through objects, giving the intersection points
% and the progressive attenuation, and the object surface angle at
% each intercept. This function assumes that the objects do not overlap. It also
% assumes that the attenuation inside an object is homogenous, constant. i.e.
% attenuation = k*distance through object.
%
% [intercept_points, obj_surface_angle, cum_atten, collision_object] = rayline(objects,line_ends)
% see addobj

%Eric Lawrey 23/11/99
%Version 1.1
%5/8/00 Version 1.1
%-Rayline returns incorrects results when a ray perfectly grases an object. That is when the
% ray passes straight through the corner of an object. Fuzz is added to the line_ends in collision
% to reduce the probability of this occuring
nobjects = length(objects);		%Find the number of objects
colall = [];
objangall = [];

linepairs = [];
colobjind = [];

%Progressively check for collision with each object
for k = 1:nobjects
   [col,objang] = collision(objects(k).vertices,line_ends);	%Find the collision with each object
   colobjind = [colobjind ones(1,length(col))*k];
   
   %Append collision information from current object to previous results from other objects
   %Record the attenuation constant of the object for each collision point
   %lineatten = [lineatten ones(1,length(col))*objects.attenuation(k)];	
   
   %Record all the collision points. Build the arrays dynamically as we don't how many 
   %collisions there will be.
   colall = [colall col];
   %Record the surface angle of the object intercepted.
   objangall = [objangall objang]; 
end

%Need to sort the intercept points (and associated surface angle and attenuation)
%so that points follow the direction of the line given
ep = 1e-6;	%Have a small tolerance for deciding whether something is vertical
%This is to overcome floating point precision effects

dx = real(line_ends(2))-real(line_ends(1));
dy = imag(line_ends(2))-imag(line_ends(1));
if (dx>(0+ep))
   [Y,I] = sort(real(colall));
elseif (dx<(0-ep))
   [Y,I] = sort(real(colall));

   I = I(length(I):-1:1);
elseif (dy>0)
   [Y,I] = sort(imag(colall));
else
   [Y,I] = sort(imag(colall));
   I = I(length(I):-1:1);
end
%I is the order in which the results should be sorted

intercept_points = colall(I);
obj_surface_angle = objangall(I);
collision_object = colobjind(I);

%lineattensort = lineatten(I);


%Convert the intercept points in to line pairs, so that the distance
%travelled inside an object can be calculated

%What we really need to do is find out whether the starting or ending
%or both the start and end began inside an object. However this is a tricky
%problem. I don't know of any efficient way of doing this so I am going
%to use a fudge. Most of the time the transmitter and receiver will
%not be inside objects. The only time that a line segment should
%start inside an object is when a rayline is traced from a previous
%intersection point. i.e. the ray from the reflection to the receiver.
%in this case the line segment will start within an object, causing
%an odd number of intersection points. 

%Check to see if the number of intercept points is odd
%If it is then we have started or ended within an object. Assume
%we started in the object, thus add the start of the line segment
%to the intercept points to form an even number, so we have line pairs.

if (mod(length(intercept_points),2)==1)
   intercept_points = [line_ends(1) intercept_points];
end

linepairs = reshape(intercept_points,2,length(intercept_points)/2);

%The attenuation of each object is associated with each point but
%only one attenuation level is used per line segment, so use the first one
ind = 1:2:length(collision_object);
lineatten = zeros(size(ind));
for k = 1:length(ind)
   obj_ind = collision_object(ind(k));
   lineatten(k) = objects(obj_ind).attenuation;	%Assume objects dont overlap
end
%For each line pair segment find the length
objpathlength = (abs(linepairs(2,:)-linepairs(1,:)));

%multiply the path through each object and the attenuation constant for the object
atten1 = cumsum(objpathlength.*lineatten);
cum_atten = zeros(1,size(intercept_points,2)+1);
cum_atten(2:2:length(cum_atten)) = atten1;
cum_atten(3:2:length(cum_atten)) = atten1(1:(length(atten1)));


refscale = 1;
refatten = [];
refscalelist = ones(1,size(collision_object,2)+1);
for k = 1:length(collision_object)
	refscale = (1-objects(collision_object(k)).reflection);
	refscalelist(k+1) = refscale;
end
refatten = -10*log10(refscalelist+eps);
if (mod(length(collision_object),2) == 1)
   refatten = [0 refatten];
end

%need to make the attenuation cumulative
refatten = cumsum(refatten);

%intercept_points

%if (mod(length(collision_object),2)==1)
%   refatten = refatten(2:length(refatten));
   %disp('odd');
%end

%refatten will be empty if the ray starts from a object intercept point 
%and does intercept with any other objects.
%if isempty(refatten)
%   refatten = [0 0];
%end



%intercept_points
%collision_object
%line_ends
%disp('reflec atten');
%refatten
%refatten(1:(length(refatten)-1))
%disp('obj atten');
%cum_atten(2:length(cum_atten))
%line_ends
%refatten
cum_atten = cum_atten+refatten;

%cum_atten(2:length(cum_atten)) = cum_atten(2:length(cum_atten))+refatten(1:(length(refatten)-1));
