function [xout,yout,zout] = rtdiffract(txloc,dist,filename,modeltype,range,horzsize,vertsize,coloraxis,N,...
   gridscale,frequency,pathlossexp)
%This function performs a shadow simulation similar to rtpathloss. rtdiffract simulates
%close in diffraction by combining the shadow calculations from multiple positions
%centred around the tx location given. 
%[xout,yout,zout] = rtdiffract(txloc,dist,filename,modeltype,range,horzsize,vertsize,coloraxis,N,...
%   gridscale,frequency,pathlossexp)
% txloc = location of the transmitter in complex coordinates (metres)
% dist = distance from txloc to do the multiple shadow calculations (metres)
% filename = name of the saved plot
% modeltype = Model to use for the shadow calculations, see genmodel
% range = x,y range to perform the simulation on
% horzsize, vertsize = size of the plots to generate in pixels
% coloraxis = colour axis to use when plotting. see caxis
% N = number of shadow calculations to use for the diffraction sim. Supported numbers are 1,2,3,4,5,10
% gridscale = scaling of the shadow grid
% frequency = frequency of the RF signals (Hz)
% pathlossexp = path loss exponent, free space = 2

%Copyright Eric Lawrey August 2000
%Version 1.1;
%6/8/00
%-Removed coloraxis hard coping
if nargin < 3
   filename = 'default';
end
if nargin < 2
   dist = 0.3;
end
switch N
case 1
   vect = 0;
case 2
   vect = [-1 1]*dist;
case 3
   vect = [i 0.5-0.866*i -0.5-0.866*i]*dist;
case 4
   vect = [1 i -1 -i]*dist;
case 5
   vect = [1 i -1 -i 0]*dist;
case 10
   ph = [30 90 150 210 270 330 60 180 300 0];
   mag = [1 1 1 1 1 1 0.3 0.3 0.3 0];
   [x,y] = pol2cart(ph/360*2*pi,mag);
   vect = (x+i*y)*dist;
otherwise
   error([num2str(N) ' number of diffraction points unsupported'])
end

for k = 1:length(vect)
   txloc2 = txloc+vect(k);
   [x,y,z] = rtpathloss(txloc2,'default',modeltype,range,horzsize,vertsize,coloraxis,gridscale,frequency,pathlossexp);
   if k >1
      ztotal = ztotal+10.^(z/10);
   else
      ztotal = 10.^(z/10);
   end
end
ztotal = ztotal/length(vect);
znew = 10*log10(ztotal);
%coloraxis = [-100 -35];
objs = genmodel(modeltype); %Get the model for the ECE building at JCU
plotresult(x,y,znew,objs,filename,horzsize,vertsize,coloraxis)
if nargout > 0 
   xout = x;
   yout = y;
   zout = znew;
end

